package com.ruoyi.ss.realName.mapper;

import com.ruoyi.ss.realName.domain.RealName;
import com.ruoyi.ss.realName.domain.RealNameQuery;
import com.ruoyi.ss.realName.domain.RealNameVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 实名认证Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-23
 */
public interface RealNameMapper
{
    /**
     * 查询实名认证
     *
     * @param id 实名认证主键
     * @return 实名认证
     */
    public RealNameVO selectRealNameById(Long id);

    /**
     * 查询实名认证列表
     *
     * @param query 实名认证
     * @return 实名认证集合
     */
    public List<RealNameVO> selectRealNameList(@Param("query")RealNameQuery query);

    /**
     * 新增实名认证
     *
     * @param realName 实名认证
     * @return 结果
     */
    public int insertRealName(RealName realName);

    /**
     * 修改实名认证
     *
     * @param realName 实名认证
     * @return 结果
     */
    public int updateRealName(@Param("data") RealName realName);

    /**
     * 删除实名认证
     *
     * @param id 实名认证主键
     * @return 结果
     */
    public int deleteRealNameById(Long id);

    /**
     * 批量删除实名认证
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRealNameByIds(Long[] ids);

    /**
     * 查询数量
     * @param query
     * @return
     */
    int selectCount(@Param("query") RealNameQuery query);
}
